import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import {max,scaleSqrt  } from 'd3';
import { useMassGeo } from './useMassGeo';
import { useCrimeData } from './useCrimeData';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';

const width = 960;
const height = 500;
const options = [
  { value: 'all', label: 'All' },
  { value: 'city', label: 'City' },
  { value: 'rural', label: 'Rural' },
  { value: 'suburb', label: 'Suburb' }
];

const CountyOptions = [
  { value: 'all', label: 'All' },
{ value: 'Barnstable', label: 'Barnstable' },
{ value: 'Berkshire', label: 'Berkshire' },
{ value: 'Bristol', label: 'Bristol' },
{ value: 'Dukes', label: 'Dukes' },
{ value: 'Essex', label: 'Essex' },
{ value: 'Franklin', label: 'Franklin' },
{ value: 'Hampden', label: 'Hampden' },
{ value: 'Hampshire', label: 'Hampshire' },
{ value: 'Middlesex', label: 'Middlesex' },
{ value: 'Nantucket', label: 'Nantucket' },
{ value: 'Norfolk', label: 'Norfolk' },
{ value: 'Plymouth', label: 'Plymouth' },
{ value: 'Suffolk', label: 'Suffolk' },
{ value: 'Worcester', label: 'Worcester' }
];


const initialValue = 'all';


const App = () => {
  const MassGeo = useMassGeo();
  const CrimeData =useCrimeData();
  
  let [data, setData] = useState(null);
  let [selectedCommunityValue, setSelectedCommunityValue] = useState(initialValue);
  let [selectedCountyValue, setSelectedCountyValue] = useState(initialValue);
  
  if (!MassGeo||!CrimeData) {
    return <pre>Loading...</pre>;
  }
	
  const filteredData=
              CrimeData.filter(d =>(selectedCommunityValue ==="all"? d : d.communtiy ===selectedCommunityValue))
              .filter(d =>(selectedCountyValue ==="all"? d : d.County ===selectedCountyValue))
  						.reverse()
              .slice(0, 5);
  
  console.log(filteredData[0])
  const cityname =d => d.City;
  const countyname =d => d.County;
  //console.log(cityname[0])
  //const countyname = d => d.County;
  const sizeValue = d =>d.crime_rate;
  //console.log(sizeValue)
  const maxRadius= 20;
	const sizeScale = scaleSqrt()
	.domain([0, max(CrimeData, sizeValue)])
	.range([0, maxRadius]);
 
  return (
    <>
      <div className="menus-container">
      <span className="dropdown-label">Choose a community:</span>
       <ReactDropdown 
        options={options}
        id="Community-select"
        value={selectedCommunityValue}
       onChange={({ value }) => setSelectedCommunityValue(value)}
      />
        <span className="dropdown-label">Choose a county:</span>
       <ReactDropdown 
        options={CountyOptions}
        id="Community-select"
        value={selectedCountyValue}
       onChange={({ value }) => setSelectedCountyValue(value)}
      />
     </div>
    <svg width={width} height={height}>
     
        <Marks
          MassGeo={MassGeo}
          CrimeData = {filteredData}
          sizeScale = {sizeScale}
          sizeValue = {sizeValue}
          cityname = {cityname}
          countyname= {countyname}
        />
     
    </svg>
   </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
